==> mysql_wa-0.1.tar.bz2: mysql_wa/index.php <==
<?php

$version = "wa 0.1";

if (!isset($_SERVER['PHP_AUTH_USER'])) {
	header('WWW-Authenticate: Basic realm="My Realm"');
	header('HTTP/1.0 401 Unauthorized');
	echo "$version\nERROR\nAUTH";
	exit;
}

echo "$version\n";

$host	= isset($_GET['HOST']) ? $_GET['HOST'] : "localhost";
$user   = $_SERVER['PHP_AUTH_USER'];	// user
$pwd	= $_SERVER['PHP_AUTH_PW'];	// password
$db	= $_REQUEST['db'];		// database to connect to
$fct	= $_REQUEST['fct'];		// function we want to use

$link = @mysql_connect($host,$user,$pwd)
	or die("ERROR\n" . mysql_errno()."\n".mysql_error()."\n");

if ($db)
	mysql_select_db($db)
	or die("ERROR\n" . mysql_errno()."\n".mysql_error()."\n");

switch($fct) {
	case "character_set_name" :
		// There no way to obtain this information
		// using a SQL command until version 4.1.0
		echo mysql_client_encoding($link);
		echo $_REQUEST['query'];
		break;
	case "query" :
		$query = $_REQUEST['query'];
		$result = mysql_query(stripslashes($query),$link);
		if (!$result) {
			echo "ERROR\n";
			echo mysql_errno($link)."\n";
			echo mysql_error($link)."\n";
			break;
		}
		echo "OK\n";
		// Output the number of fields
		echo mysql_num_fields($result)."\n";
		// Output the fields descriptions
		while ($field=mysql_fetch_field($result)) {
			echo $field->name.",".$field->table.",".
				$field->max_length.",".
				$field->max_length.",".
				$field->not_null.",".
				$field->type."\n";
		}
		// Output number of row
		echo mysql_num_rows($result)."\n";
		// Output the result
		while ($row=mysql_fetch_row($result)) {
			echo implode(",", $row)."\n";
		}
		break;
	default :
}


mysql_close($link);


?>

==> mysql_wa-0.2.tar.bz2: mysql_wa/index.php <==
<?php

// used on the client side for sanity check
$version = "wa 2";

if (!isset($_SERVER['PHP_AUTH_USER'])) {
	header('WWW-Authenticate: Basic realm="My Realm"');
	header('HTTP/1.0 401 Unauthorized');
	echo "$version\nERROR\nAUTH";
	exit;
}

echo "$version\n";

$host	= isset($_GET['HOST']) ? $_GET['HOST'] : "localhost";
$user   = $_SERVER['PHP_AUTH_USER'];	// user
$pwd	= $_SERVER['PHP_AUTH_PW'];	// password
$db	= $_REQUEST['db'];		// database to connect to
$fct	= $_REQUEST['fct'];		// function we want to use

$link = @mysql_connect($host,$user,$pwd)
	or die("ERROR\n" . mysql_errno()."\n".mysql_error()."\n");

if ($db)
	mysql_select_db($db)
	or die("ERROR\n" . mysql_errno()."\n".mysql_error()."\n");

switch($fct) {
	case "character_set_name" :
		// There no way to obtain this information
		// using a SQL command until version 4.1.0
		echo mysql_client_encoding($link);
		echo $_REQUEST['query'];
		break;
	case "query" :
		$query = $_REQUEST['query'];
		$result = mysql_query(stripslashes($query),$link);
		if (!$result) {
			echo "ERROR\n";
			echo mysql_errno($link)."\n";
			echo mysql_error($link)."\n";
			break;
		}
		echo "OK\n";
		// Output the number of fields
		echo mysql_num_fields($result)."\n";
		// Output the fields descriptions
		while ($field=mysql_fetch_field($result)) {
			echo $field->name.",".$field->table.",".
				$field->max_length.",".
				$field->max_length.",".
				$field->not_null.",".
				$field->type."\n";
		}
		// Output number of row
		echo mysql_num_rows($result)."\n";
		// Output the result
		// before the values, we output the real length of
		// the field. So we don't have to encode field separator
		// when it appears in the field value.
		while ($row=mysql_fetch_row($result)) {
			echo implode(",",mysql_fetch_lengths($result))."\n";
			echo implode(",", $row)."\n";
		}
		break;
	default :
}


mysql_close($link);


?>
